==> jc-1.4.0.tar.gz: polyglot/ast/ConstructorCall__24Kind.h <==
// public class polyglot.ast.ConstructorCall$Kind

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8c6d2a41258315be polyglot_ast_ConstructorCall__24Kind
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_ConstructorCall__24Kind_H_
#define _JC_polyglot_ast_ConstructorCall__24Kind_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs	_jc_polyglot_ast_ConstructorCall__24Kind$sub_refs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs	_jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$refs	_jc_polyglot_ast_ConstructorCall__24Kind$refs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$nonrefs	_jc_polyglot_ast_ConstructorCall__24Kind$nonrefs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$object	_jc_polyglot_ast_ConstructorCall__24Kind$object;

typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vmethods	_jc_polyglot_ast_ConstructorCall__24Kind$vmethods;
typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vtable	_jc_polyglot_ast_ConstructorCall__24Kind$vtable;
typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vtype	_jc_polyglot_ast_ConstructorCall__24Kind$vtype;

// Constructors
extern void _jc_polyglot_ast_ConstructorCall__24Kind$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_ast_ConstructorCall__24Kind$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_ast_ConstructorCall__24Kind$vmethods {
};

// Vtable
struct _jc_polyglot_ast_ConstructorCall__24Kind$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_ConstructorCall__24Kind$vmethods	polyglot_ast_ConstructorCall__24Kind;
};

// Vtype
struct _jc_polyglot_ast_ConstructorCall__24Kind$vtype {
	_jc_type			type;
	_jc_polyglot_ast_ConstructorCall__24Kind$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ast_ConstructorCall__24Kind$refs {
    _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs	polyglot_ast_ConstructorCall__24Kind;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_ConstructorCall__24Kind$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs	polyglot_ast_ConstructorCall__24Kind;
};

// Object instance structure
struct _jc_polyglot_ast_ConstructorCall__24Kind$object {
	_jc_polyglot_ast_ConstructorCall__24Kind$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_ConstructorCall__24Kind$vtype	*vtype;
	_jc_polyglot_ast_ConstructorCall__24Kind$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_ConstructorCall__24Kind$vtype _jc_polyglot_ast_ConstructorCall__24Kind$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_ConstructorCall__24Kind, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_ConstructorCall__24Kind$class_object;

#endif	/* _JC_polyglot_ast_ConstructorCall__24Kind_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/ConstructorCall__24Kind.h <==
// public class polyglot.ast.ConstructorCall$Kind

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c6d2a41258315be polyglot_ast_ConstructorCall__24Kind
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_ConstructorCall__24Kind_H_
#define _JC_polyglot_ast_ConstructorCall__24Kind_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs	_jc_polyglot_ast_ConstructorCall__24Kind$sub_refs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs	_jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$refs	_jc_polyglot_ast_ConstructorCall__24Kind$refs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$nonrefs	_jc_polyglot_ast_ConstructorCall__24Kind$nonrefs;
typedef struct _jc_polyglot_ast_ConstructorCall__24Kind$object	_jc_polyglot_ast_ConstructorCall__24Kind$object;

typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vmethods	_jc_polyglot_ast_ConstructorCall__24Kind$vmethods;
typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vtable	_jc_polyglot_ast_ConstructorCall__24Kind$vtable;
typedef const struct _jc_polyglot_ast_ConstructorCall__24Kind$vtype	_jc_polyglot_ast_ConstructorCall__24Kind$vtype;

// Constructors
extern void _jc_polyglot_ast_ConstructorCall__24Kind$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_ast_ConstructorCall__24Kind$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ast_ConstructorCall__24Kind$vmethods {
};

// Vtable
struct _jc_polyglot_ast_ConstructorCall__24Kind$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_ConstructorCall__24Kind$vmethods	polyglot_ast_ConstructorCall__24Kind;
};

// Vtype
struct _jc_polyglot_ast_ConstructorCall__24Kind$vtype {
	_jc_type			type;
	_jc_polyglot_ast_ConstructorCall__24Kind$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ast_ConstructorCall__24Kind$refs {
    _jc_polyglot_ast_ConstructorCall__24Kind$sub_refs	polyglot_ast_ConstructorCall__24Kind;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_ConstructorCall__24Kind$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_ConstructorCall__24Kind$sub_nonrefs	polyglot_ast_ConstructorCall__24Kind;
};

// Object instance structure
struct _jc_polyglot_ast_ConstructorCall__24Kind$object {
	_jc_polyglot_ast_ConstructorCall__24Kind$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_ConstructorCall__24Kind$vtype	*vtype;
	_jc_polyglot_ast_ConstructorCall__24Kind$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_ConstructorCall__24Kind$vtype _jc_polyglot_ast_ConstructorCall__24Kind$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_ConstructorCall__24Kind, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_ConstructorCall__24Kind$class_object;

#endif	/* _JC_polyglot_ast_ConstructorCall__24Kind_H_ */
